[![pipeline status](https://gitlab.com/HnBI/platform-as-a-service/infrastructure/badges/master/pipeline.svg)](https://gitlab.com/HnBI/platform-as-a-service/infrastructure/commits/master)

This repository contains terraform code for various infrastructure components of our platform. Every component defined in this repo should adhere to the following principles

- Independent (from other components)
- short and descriptive naming without the provider's name unless there is a conflict
- Contains a README
- `.gitlab-ci.yml` (at the root of the component) to include per environment/region CI configuration. This should only contain component level global config and includes of the environment/region CI configuration
- `environments/ENVIRONMENT/REGION/.gitlab-ci.yml` (per environment/region) that defines the CI/CD workflow
- terraform code in `terraform` sub-folder and tfvar files in `environments/ENV/REGION` sub-folder

Below is a list of components configured:
- [aws-account-bootstrap](./aws-account-bootstrap/README.md)
- [datadog](./datadog/README.md)
- [iam](./iam/README.md)
- [organization](./organization/README.md)
- [route53-zones](./route53-zones/README.md)
- [s3-bucket](./s3-bucket/README.md)
- [vpc](./vpc/README.md)
- [vpn](./vpn/README.md)

## Repo directory structure
Following is the folder structure for the repo:

```
├── .gitlab
│   ├── templates                        # Common Gitlab templates to reuse at component level
│   │   ├── GLOBAL-GITLAB-TEMPLATES.yml  # generic reusable job definitions
├── COMPONENT-1                          # Independant infrastructure entity
│   ├── environments                     # environment configs
│   │   ├── ENV                          # Eg: billing/dev/prod
|   |       ├── REGION                   # Eg: eu-west-1
|   |           ├── .gitlab-ci.yml       # gitlab-ci file defining tags per env/region
|   |           ├── backend.tfvars       # Terraform backend config
|   |           ├── terraform.tfvars     # Terraform vars-file
│   ├── terraform                        # Terraform source code for the component
│   │   ├── *.tf
│   ├── .gitlab-ci.yml                   # component-level Gitlab CI that includes en/region Gitlab CI definitions
│   ├── README.md                        # component-level README
├── README.md                            # Root level README
├── .gitlab-ci.yml                       # Root level Gitlab CI that includes component level CI definitions
└── .gitignore
```

## Terraform
Terraform is used to create and manage the components in this repo and the workflow should always be run as part of the Gitlab pipeline. However, if you ever need to run the commands for testing purposes, see below:

```bash
cd COMPONENT/terraform
aws-vault exec <PROFILE> -- terraform init -reconfigure -backend-config=../environments/ENVIRONMENT/REGION/backend.tfvars
aws-vault exec <PROFILE> -- terraform plan -var-file=../environments/ENVIRONMENT/REGION/terraform.tfvars -out plan.out
aws-vault exec <PROFILE> -- terraform apply plan.out
```

## Gitlab CI
Gitlab CI automatically executes the `.gitlab-ci.yml` in the root of the project. As per Gitlab examples, the project root level `.gitlab-ci.yml` file is to co-ordinate the individual component pipelines and define some global variables.

#### Gotchas
- Pipelines are not executed on branch creation but on merge requests due to https://gitlab.com/gitlab-org/gitlab-ce/issues/19232#note_101824408
- While `extends` presents us from a single Gitlab CI config file, merging of the files only caters for top level keys and sub-keys are overwritten with which ever file is included last (reason for the current runner tag config)