data "aws_caller_identity" "current" {}

resource "aws_s3_bucket" "terraform-state-bucket" {
  bucket = "terraform-state-${data.aws_caller_identity.current.account_id}"
  acl    = "private"

  versioning {
    enabled = true
  }

  server_side_encryption_configuration {
    rule {
      apply_server_side_encryption_by_default {
        sse_algorithm = "AES256"
      }
    }
  }

  tags = {
    name       = "terraform-state-${data.aws_caller_identity.current.account_id}"
    created_by = "terraform"
    owner      = "paas"
  }
}

resource "aws_dynamodb_table" "terraform-state-lock" {
  name           = "terraform-state-lock-${data.aws_caller_identity.current.account_id}"
  hash_key       = "LockID"
  read_capacity  = 20
  write_capacity = 20

  attribute {
    name = "LockID"
    type = "S"
  }

  tags = {
    name       = "terraform-state-lock-${data.aws_caller_identity.current.account_id}"
    created_by = "terraform"
    owner      = "paas"
  }
}
