# IAM

Currently configured to create:

* IAM Users
* IAM Groups

## Adding a new user

1. Open `environments/billing/global/terraform.tfvars` in your favoured text editor.
2. In the `users` object, add a new user from the template below:
   * please note that users will need to be added in alphabetical order, until terraform's foreach is released.

```terraform
johnsmith = {
    username = "johnsmith"
    email = "johnsmith@hollandandbarrett.com"
    keybase_username = "johnsmith"
    team = "paas"
    groups = [
      "admin"
    ]
}
```
> replacing `johnsmith` with the id of the user you wish to create.

3. Chronologically add the user into the `users_list_order` object. (should not be required in future releases so update this note accordingly)

### Explanation of the user object above

* `username`: the username of the AWS IAM profile.
* `email`: the registered email of the user.
* `keybase_username`: the username of the Keybase profile, which is required to be setup beforehand.
* `team`: the team that the user belongs to.
* `groups`: a group to assign the user to, usually one with attached policies.

## Adding a new group

1. Open `environments/billing/global/terraform.tfvars` in your favoured text editor.
2. In the `groups` object, add a new group from the template below:

```terraform
admin = {
    groupname = "admin"
    policy_arns = [
      "arn:aws:iam::aws:policy/AdministratorAccess"
    ]
}
```

> replacing `admin` with the id of the group you wish to create.

### Explanation of the group object above

* `groupname`: the id of the AWS IAM group
* `policy_arns`: a list of policies to be attached the group.

## Usage

Example terraform run:
```bash
$ terraform init -backend-config=../environments/billing/global/backend.tfvars
$ terraform plan -out=/tmp/terraform.plan -var-file=../environments/billing/global/terraform.tfvars
$ terraform apply /tmp/terraform.plan
```

## Output

After the terraform has been applied then it will output the list of users that have been created. In the list of `user_logins` you will find an attribute named `encrypted_password` under the newly created user. Give this encrypted password to the new user. They will need to decrypt this password using keybase. E.g. on a Mac machine copy the password, then run:

* `pbpaste | base64 --decode | keybase pgp decrypt`

Which will then output the decrypted password, which along with the username can be used to sign into the console at: https://hbi-billing.signin.aws.amazon.com/console .

The user will need to setup MFA to be able to access any resources on AWS, on the My Security Credentials page: https://console.aws.amazon.com/iam/home#/security_credentials.


## References

* [https://aws.amazon.com/iam/](https://aws.amazon.com/iam/)
