resource "aws_iam_role" "gitlab_ci" {
  name               = "GitlabCI"
  assume_role_policy = data.aws_iam_policy_document.all_accounts_assume.json
}

data "aws_iam_policy_document" "s3_teams_ci_permissions" {
  statement {
    sid = "AllowReadWrite"

    actions = [
      "s3:DeleteObject",
      "s3:DeleteObjectTagging",
      "s3:DeleteObjectVersion",
      "s3:DeleteObjectVersionTagging",
      "s3:PutObject",
      "s3:PutObjectAcl",
      "s3:PutObjectTagging",
      "s3:PutObjectVersionAcl",
      "s3:PutObjectVersionTagging",
      "s3:GetObject",
      "s3:GetObjectAcl",
      "s3:GetObjectTagging",
      "s3:GetObjectVersion",
      "s3:GetObjectVersionAcl",
      "s3:GetObjectVersionTagging",
      "S3:RestoreObject"
    ]

    resources = [
      "arn:aws:s3:::hbi-*/*"
    ]
  }

  statement {
    sid = "AllowListBucket"

    actions = [
      "s3:ListBucket",
      "s3:ListBucketVersions",
      "s3:ListBucketMultiPartUploads",
    ]

    resources = [
      "arn:aws:s3:::hbi-*"
    ]
  }
}

data "aws_iam_policy_document" "all_accounts_assume" {
  statement {
    actions = ["sts:AssumeRole"]

    principals {
      type        = "AWS"
      identifiers = concat(["arn:aws:iam::$data.aws_caller_identity.current.account_id}:root"], var.trusted_account_ids)
    }
  }
}

resource "aws_iam_role_policy" "gitlab_ci" {
  name_prefix = "GitlabCI"
  role        = aws_iam_role.gitlab_ci.id
  policy      = data.aws_iam_policy_document.s3_teams_ci_permissions.json
}
