resource "aws_organizations_organization" "org" {
  aws_service_access_principals = var.org.service_access_principals
  enabled_policy_types          = var.org.policy_types
  feature_set                   = var.org.feature_set
}

resource "aws_organizations_account" "org_account" {
  count = length(keys(var.org_accounts))

  name                       = var.org_accounts[element(keys(var.org_accounts), count.index)].account_name
  email                      = var.org_accounts[element(keys(var.org_accounts), count.index)].email
  parent_id                  = aws_organizations_organization.org.roots[0].id
  role_name                  = "OrganizationAccountAccessRole"
  iam_user_access_to_billing = var.org_accounts[element(keys(var.org_accounts), count.index)].iam_user_access_to_billing
}

# resource "aws_organizations_organizational_unit" "org_ou" {
#   name = ""
#   parent_id = ""
# }

data "aws_iam_policy_document" "org_cloudtrail" {
  statement {
    sid    = "DenyCloudtrailConfigSCP"
    effect = "Deny"

    actions = [
      "cloudtrail:AddTags",
      "cloudtrail:CreateTrail",
      "cloudtrail:DeleteTrail",
      "cloudtrail:RemoveTags",
      "cloudtrail:StartLogging",
      "cloudtrail:StopLogging",
      "cloudtrail:UpdateTrail"
    ]

    resources = ["*"]
  }
}

resource "aws_organizations_policy" "org_cloudtrail" {
  name        = "org_cloudtrail_scp"
  content     = data.aws_iam_policy_document.org_cloudtrail.json
  type        = "SERVICE_CONTROL_POLICY"
  description = "SCP that denies cloudtrail configuration changes in child accounts"
}

# resource "aws_organizations_policy_attachment" "org_cloudtrail" {
#   policy_id = aws_organizations_policy.org_cloudtrail.id
#   target_id = aws_organizations_organization.org.roots[0].id  # ID of root/OU/account number
# }
