data "aws_caller_identity" "current" {}

resource "aws_s3_bucket" "bucket" {
  count = length(var.s3_buckets)

  bucket              = var.s3_buckets[count.index].name
  bucket_prefix       = var.s3_buckets[count.index].prefix
  acl                 = var.s3_buckets[count.index].acl
  policy              = var.s3_buckets[count.index].policy != null ? var.s3_buckets[count.index].policy : templatefile("${path.module}/templates/${var.s3_buckets[count.index].type}.tmpl", merge(var.s3_buckets[count.index], local.dynamic_policy_vars))
  force_destroy       = var.s3_buckets[count.index].force_destroy
  acceleration_status = var.s3_buckets[count.index].acceleration_status
  region              = var.s3_buckets[count.index].region
  request_payer       = var.s3_buckets[count.index].request_payer

  tags = merge(local.required_tags, lookup(var.s3_buckets[count.index], "tags", {}))

  # website configuration
  dynamic "website" {
    for_each = lookup(var.s3_buckets[count.index], "website_config", {}) == {} ? null : [var.s3_buckets[count.index].website_config]

    content {
      index_document           = website.value.index_document
      error_document           = website.value.error_document
      redirect_all_requests_to = website.value.redirect_all_requests_to
      routing_rules            = website.value.routing_rules
    }
  }
}
