# VPC

Uses the Hashicorp verified Terraform module which creates VPC resources on AWS

* [https://registry.terraform.io/modules/terraform-aws-modules/vpc/aws](https://registry.terraform.io/modules/terraform-aws-modules/vpc/aws)

Currently configured to create:

* VPC
* Subnets based on the number of availability zones in the Region specified
* Public, Private & Database Subnets
* Internet Gateway
* NAT Gateway per availability zone including EIP
* Route Tables

See module for additional resources

## CIDR Ranges

| CIDR Range | Location | AWS Account | AWS Account Name |
| - | - | - | - |
| 10.1.0.0/20  | AWS (new) | 171360132227 | billing |
| 10.1.16.0/20 | AWS (new) | 051326774509 | services |
| 10.1.32.0/20 | AWS (new) | 253009987341 | audit |
| 10.1.48.0/20 | AWS (new) | 048958980748 | sandbox |
| 10.1.64.0/20 | AWS (new) | 448714108511 | dev |
| 10.1.80.0/20 | AWS (new) | 482520917892 | prod |

The VPCs are allocated a `/20` CIDR Range like the following:

```bash
$ ipcalc -b 10.1.0.0/20                                                                                                                                                                                                                      (⎈ :)
Address:   10.1.0.0
Netmask:   255.255.240.0 = 20
Wildcard:  0.0.15.255
=>
Network:   10.1.0.0/20
HostMin:   10.1.0.1
HostMax:   10.1.15.254
Broadcast: 10.1.15.255
Hosts/Net: 4094                  Class A, Private Internet
```

The subnets/azs are each auto allocated a `/24` based off cidr range like the following:

```bash
$ ipcalc -b 10.1.0.0/24                                                                                                                                                                                                                      (⎈ :)
Address:   10.1.0.0
Netmask:   255.255.255.0 = 24
Wildcard:  0.0.0.255
=>
Network:   10.1.0.0/24
HostMin:   10.1.0.1
HostMax:   10.1.0.254
Broadcast: 10.1.0.255
Hosts/Net: 254                   Class A, Private Internet
```

## Usage

Create the backend configuration for the environment/region:

```bash
$ cat vpc/environments/services/eu-west-1/backend.tfvars
bucket         = "terraform-state-051326774509"
dynamodb_table = "terraform-state-lock-051326774509"
region         = "eu-west-1"
key            = "vpc/services/eu-west-1/vpc.tfstate
```

Create the tfvars file for the environment/region:

```bash
$ cat vpc/environments/services/eu-west-1/terraform.tfvars
region      = "eu-west-1"
environment = "services"
cidr        = "10.10.0.0/16" # 10.10.0.0-10.10.255.255
common_tags = {
  "created_by"  = "terraform"
  "application" = "infrastructure"
  "owner"       = "paas"
}
```

Example terraform run:
```bash
$ ENVIRONMENT=[SET_SPECIFIC_ENVIRONMENT]
$ terraform init -backend-config=../environments/${ENVIRONMENT}/global/backend.tfvars
$ terraform plan -out=/tmp/terraform.plan -var-file=../environments/${ENVIRONMENT}/global/terraform.tfvars
$ terraform apply /tmp/terraform.plan
```

## References

* [https://aws.amazon.com/vpc/](https://aws.amazon.com/vpc/)
* [https://registry.terraform.io/modules/terraform-aws-modules/vpc/aws](https://registry.terraform.io/modules/terraform-aws-modules/vpc/aws)
