data "aws_availability_zones" "available" {
  state = "available"
}

locals {
  required_tags = {
    application = "infrastructure"
    owner       = "paas"
    created_by  = "terraform"
    environment = var.vpc.environment
  }
  eks_tags = {
    "kubernetes.io/cluster/eks-cluster-${local.required_tags.environment}" = "shared" # required for EKS cluster service discovery
  }
  private_subnet_tags = {
    type = "private"
  }
  public_subnet_tags = {
    type = "public"
  }
  database_subnet_tags = {
    type = "database"
  }
}

module "vpc" {
  source  = "terraform-aws-modules/vpc/aws"
  version = "2.7.0"

  name = var.vpc.environment
  cidr = var.vpc.cidr

  azs              = data.aws_availability_zones.available.names
  public_subnets   = [cidrsubnet(var.vpc.cidr, 4, 0), cidrsubnet(var.vpc.cidr, 4, 1), cidrsubnet(var.vpc.cidr, 4, 2)] # Example: public/254*3 - 10.1.0.0/24, 10.1.1.0/24, 10.1.2.0/24
  private_subnets  = [cidrsubnet(var.vpc.cidr, 4, 3), cidrsubnet(var.vpc.cidr, 4, 4), cidrsubnet(var.vpc.cidr, 4, 5)] # Example: private/254*3 - 10.1.3.0/24, 10.1.4.0/24, 10.1.5.0/24
  database_subnets = [cidrsubnet(var.vpc.cidr, 4, 6), cidrsubnet(var.vpc.cidr, 4, 7), cidrsubnet(var.vpc.cidr, 4, 8)] # Example: database/254*3 - 10.1.6.0/24, 10.1.7.0/24, 10.8.12.0/24

  enable_dns_hostnames   = var.vpc.enable_dns_hostnames
  enable_dns_support     = var.vpc.enable_dns_support
  enable_nat_gateway     = var.vpc.enable_nat_gateway
  one_nat_gateway_per_az = var.vpc.one_nat_gateway_per_az

  tags = merge(local.required_tags, var.tags)

  vpc_tags             = var.vpc.add_eks_tags ? local.eks_tags : {}
  private_subnet_tags  = var.vpc.add_eks_tags ? merge(local.private_subnet_tags, local.eks_tags) : local.private_subnet_tags
  public_subnet_tags   = var.vpc.add_eks_tags ? merge(local.public_subnet_tags, local.eks_tags) : local.public_subnet_tags
  database_subnet_tags = local.database_subnet_tags
}
