# VPN

Pritunl is an Enterprise Distributed OpenVPN and IPsec Server.

It can be used to provide simple remote access to interconnect networks across regions and provide reliable remote access with automatic failover that can scale horizontally.

See the official website for more details: https://pritunl.com/ and https://docs.pritunl.com/docs/

See H&B supporting documentation: https://hbidigital.atlassian.net/wiki/spaces/PAAS/pages/800096643/Pritunl

## Overview

Creates the following AWS resources:

* IAM Profile
  * Permissions to obtain secret from AWS ssm
  * Permissions to update VPC Route Table (required for site-to-site IPsec links)
  * Permissions to update Route53
* Security Group
  * Provide HTTP/HTTPS/UDP access to Pritunl Instances
* Launch Configuration & Autoscaling Group
  * Automated deployment of Pritunl server
  * Provides high availability, failover and rolling deployments
* Network Loadbalancer
  * Provide HTTP/HTTPS access to the Pritunl Web UI
  * Provide VPN Client access to the Pritunl VPN Server using UDP Protocol

Pritunl recommends using Centos or Oracle Linux for the Pritunl server due to SELinux capabilities.

## Prerequisite

Pritunl uses MongoDB to store all data including vpn certificates and keys.

The MongoDB password should be manually pushed to aws ssm as an encrypted SecureString before running the terraform for the first time. This provides a secure method for Pritunl instances to obtain the MongoDB password during boot using IAM permissions to access the secret in aws ssm.

```bash
aws-vault exec <PROFILE> -- aws ssm put-parameter --name --type SecureString --type SecureString --value <MONGODB_ADMIN_PASSWORD>
```

## Usage

Example terraform run:

```bash
$ ENVIRONMENT=[SET_SPECIFIC_ENVIRONMENT]
$ REGION=[SET_SPECIFIC_REGION]
$ terraform init -reconfigure -backend-config=../environments/${ENVIRONMENT}/${REGION}/backend.tfvars
$ terraform plan -out=/tmp/terraform.plan -var-file=../environments/${ENVIRONMENT}/${REGION}/terraform.tfvars
$ terraform apply /tmp/terraform.plan
```

When setting up Pritunl for the first time you will need to connect to one of the Pritunl instances and obtain the initial admin password for Pritunl.

```bash
$ sudo pritunl default-password
Administrator default password:
  username: "pritunl"
  password: "PRITUNL_GENERATED_PASSWORD"
```

## Configuration

We have decided not to automate the Pritunl configuration. It is worth noting that there is a Terraform provider available from Pritunl if we do decide to automate this in the future https://github.com/pritunl/terraform-provider-pritunl

Initial Pritunl Setup Steps (https://docs.pritunl.com/docs/configuration-5)

* Obtain the initial pritunl Administrator password by accessing one of the instances and running `sudo pritunl default-password`
* Login via the Web UI: https://pritunl.eu-west-1.services.hbi.systems
  * Initially you will get a TLS warning `Your connection is not private` as letsencrypt has not been set yet
* Settings
  * New Password: [update and store in keybase team]
  * Public Address: `pritunl.eu-west-1.services.hbi.systems`
  * Lets Encrypt Domain: `pritunl.eu-west-1.services.hbi.systems`
* Users
  * Add Organization
    * Name: `hbi`
  * Add User
    * Name: `test`
    * Select an organization: `hbi`
* Servers
  * Add Server
    * Name: `hbi-services`
    * Port: `11500` - The Security Group will need updating if setting to different port  
    * Protocl: `udp`
    * Virtual Network: `192.168.234.0/24` - VPC resources will need to include this Virtual Network in there Security Groups to provide access over when connected via the VPN
    * Enable Two-Step Authentication
    * Add
  * Attach Organization
    * Select an organization: `hbi`
    * Select a server: `hbi-services`
  * Remove route: `0.0.0.0/0`
  * Add Route
    * Network: `10.1.16.0/20`
    * Select a server: `hbi-services`
  * Start Server

## Troubleshooting

```bash
cat /var/log/cloud-init.log
cat /var/log/cloud-init-output.log
cat /var/lib/cloud/instance/user-data.txt

systemctl status pritunl
journalctl -fu pritunl
less /var/log/pritunl.log
cat /etc/pritunl.conf

mongo "mongodb+srv://hbi-paas-mongodb-nyd8u.mongodb.net/test" --username pritunl

netstat -ntulp
netstat -nr
```

## References

* https://pritunl.com/
* https://docs.pritunl.com/
