resource "aws_iam_role" "pritunl" {
  name = "pritunl"
  tags = merge(local.required_tags, var.tags)

  assume_role_policy = <<EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Action": "sts:AssumeRole",
      "Principal": {
        "Service": "ec2.amazonaws.com"
      },
      "Effect": "Allow",
      "Sid": ""
    }
  ]
}
EOF
}

resource "aws_iam_instance_profile" "pritunl" {
  name = "pritunl"
  role = aws_iam_role.pritunl.name
}

data "aws_iam_policy_document" "pritunl" {
  statement {
    sid = "GetSecrets"

    actions = [
      "ssm:GetParameter",
      "kms:Decrypt"
    ]

    resources = [
      "arn:aws:ssm:${data.aws_region.current.name}:${data.aws_caller_identity.current.account_id}:parameter/pritunl/*",
      "arn:aws:kms:${data.aws_region.current.name}:${data.aws_caller_identity.current.account_id}:key/*"
    ]
  }
}

resource "aws_iam_role_policy" "pritunl" {
  name = "pritunl"
  role = aws_iam_role.pritunl.id
  policy = data.aws_iam_policy_document.pritunl.json
}
