resource "aws_lb" "pritunl" {
  name                       = "pritunl"
  internal                   = false
  load_balancer_type         = "network"
  subnets                    = data.terraform_remote_state.vpc.outputs.vpc.public_subnets
  enable_deletion_protection = false

  tags = merge(local.required_tags, var.tags)
}

resource "aws_lb_target_group" "pritunl-udp" {
  name                 = "pritunl-udp-11500"
  port                 = "11500"
  protocol             = "UDP"
  vpc_id               = data.terraform_remote_state.vpc.outputs.vpc.vpc_id
  deregistration_delay = "300"
  health_check {
    interval            = "10"
    port                = "80"
    protocol            = "TCP"
    healthy_threshold   = "3"
    unhealthy_threshold = "3"
  }

  tags = merge(local.required_tags, var.tags)
}

resource "aws_lb_listener" "pritunl-listener-udp" {
  load_balancer_arn = aws_lb.pritunl.arn
  port              = "11500"
  protocol          = "UDP"
  default_action {
    target_group_arn = aws_lb_target_group.pritunl-udp.arn
    type             = "forward"
  }
}

resource "aws_lb_target_group" "pritunl-https" {
  name                 = "pritunl-https"
  port                 = "443"
  protocol             = "TCP"
  vpc_id               = data.terraform_remote_state.vpc.outputs.vpc.vpc_id
  deregistration_delay = "300"
  health_check {
    interval            = "10"
    port                = "443"
    protocol            = "TCP"
    healthy_threshold   = "3"
    unhealthy_threshold = "3"
  }

  tags = merge(local.required_tags, var.tags)
}

resource "aws_lb_listener" "pritunl-listener-https" {
  load_balancer_arn = aws_lb.pritunl.arn
  port              = "443"
  protocol          = "TCP"
  # certificate_arn   = aws_acm_certificate_validation.pritunl_nlb_validated_cert.certificate_arn
  default_action {
    target_group_arn = aws_lb_target_group.pritunl-https.arn
    type             = "forward"
  }
}

resource "aws_lb_target_group" "pritunl-http" {
  name                 = "pritunl-http"
  port                 = "80"
  protocol             = "TCP"
  vpc_id               = data.terraform_remote_state.vpc.outputs.vpc.vpc_id
  deregistration_delay = "300"
  health_check {
    interval            = "10"
    port                = "80"
    protocol            = "TCP"
    healthy_threshold   = "3"
    unhealthy_threshold = "3"
  }

  tags = merge(local.required_tags, var.tags)
}

resource "aws_lb_listener" "pritunl-listener-http" {
  load_balancer_arn = aws_lb.pritunl.arn
  port              = "80"
  protocol          = "TCP"
  default_action {
    target_group_arn = aws_lb_target_group.pritunl-http.arn
    type             = "forward"
  }
}

data "aws_route53_zone" "selected" {
  name = "${data.aws_region.current.name}.${var.environment}.hbi.systems"
}

resource "aws_route53_record" "pritunl" {
  zone_id = data.aws_route53_zone.selected.zone_id
  name    = "pritunl.${data.aws_region.current.name}.${var.environment}.hbi.systems"
  type    = "A"

  alias {
    name                   = "${aws_lb.pritunl.dns_name}"
    zone_id                = "${aws_lb.pritunl.zone_id}"
    evaluate_target_health = true
  }
}
